package com.tomtom.business.android.btdemo;

import java.util.ArrayList;
import java.util.List;

import android.app.Activity;
import android.bluetooth.BluetoothDevice;
import android.content.Intent;
import android.graphics.Color;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.TextView;

/**
 * Activity to choose LINK device.
 */
public class Choice extends Activity
{
    public final static String INTENT_LIST    = Choice.class.getName() + ".LIST";
    public final static String INTENT_CURRENT = Choice.class.getName() + ".CURRENT";
    public final static String INTENT_RESULT  = Choice.class.getName() + ".RESULT";
    
    private final static String TAG = "btemo.choice";
    
    private int status              = Activity.RESULT_OK;
    private BluetoothDevice prev    = null;
    private BluetoothDevice choosen = null;
    
    /**
     * @see android.app.Activity#onCreate(android.os.Bundle)
     */
    @Override
    protected void onCreate(Bundle state)
    {
        super.onCreate(state);
        Log.i(TAG,"start LINK choice");

        this.setContentView(R.layout.choice);

        Intent intent = this.getIntent();
        this.prev = intent.getParcelableExtra(INTENT_CURRENT);

        final ArrayList<BluetoothDevice> list = intent.getParcelableArrayListExtra(INTENT_LIST);
        final ArrayAdapter adapter = new MyAdapter(list);
        ListView listView = (ListView) this.findViewById(R.id.choice_list);
        listView.setAdapter(adapter);
        listView.setOnItemClickListener(new AdapterView.OnItemClickListener()
        {
            public void onItemClick(AdapterView<?> parent, View view, int pos, long id)
            {
                choosen = list.get(pos);
                finish();
            }
        });
    }
    
    
    /**
     * @see android.app.Activity#onBackPressed()
     */
    @Override
    public void onBackPressed()
    {
        Log.i(TAG,"LINK choice cancelled");
        this.status = Activity.RESULT_CANCELED;
        super.onBackPressed();
    }
    
    /**
     * @see android.app.Activity#finish()
     */
    @Override
    public void finish()
    {
        // pass discovery result back to main activity
        Intent intent = this.getIntent();
        intent.putExtra(INTENT_RESULT,this.choosen);
        
        this.setResult(this.status,intent);
        super.finish();
    }
    
    /**
     * We use an own adapter to customize the list layout.
     * @param <BluetoothDevice>
     */
    private class MyAdapter extends ArrayAdapter<BluetoothDevice>
    {
        private final static int LAYOUT = R.layout.choice_item;
        
        /**
         * ct.
         * @param objects the list of objects to show.
         */
        public MyAdapter(List<BluetoothDevice> objects)
        {
            super(Choice.this, LAYOUT, objects);
        }
        
        /**
         * @see android.widget.ArrayAdapter#getView(int, android.view.View, android.view.ViewGroup)
         */
        @Override
        public View getView(int pos, View view, ViewGroup parent)
        {
            LineHolder holder = null;
            
            // create view on demand
            if (view == null)
            {
                LayoutInflater inflater = Choice.this.getLayoutInflater();
                view = inflater.inflate(LAYOUT,parent,false);
                
                // Cache both in the view 
                TextView name    = (TextView) view.findViewById(R.id.choice_name);
                TextView address = (TextView) view.findViewById(R.id.choice_address);
                
                holder = new LineHolder(name,address);
                view.setTag(holder);
            }
            else
            {
                holder = (LineHolder) view.getTag();
            }

            // apply values
            BluetoothDevice current = this.getItem(pos);
            holder.name.setText(current.getName());
            holder.address.setText(getString(R.string.ui_label_choose_address,current.getAddress()));
            
            // highlight previously chosen device if in list
            if (prev != null && prev.equals(current))
                view.setBackgroundColor(Color.rgb(241,207,142)); // a nicely chilled orange ;)
            else
                view.setBackgroundColor(Color.WHITE); // a nicely chilled orange ;)
            
            return view;
        }
        
        /**
         * Helper class to hold the lines text views.
         */
        private class LineHolder
        {
            private TextView name    = null;
            private TextView address = null;
            
            /**
             * constructor.
             * @param name
             * @param address
             */
            private LineHolder(TextView name, TextView address)
            {
                this.name = name;
                this.address = address;
            }
            
        }
    }
}
