package com.tomtom.business.android.btdemo;

import android.content.SharedPreferences;
import android.content.SharedPreferences.Editor;

/**
 * Helper class to load and save settings.
 */
public class Settings
{
    /**
     * The LINK's BT address is stored using this name.
     */
    public final static String LINK_ADDRESS = "link.address";
    
    /**
     * This intent is broadcasted by the Response thread to notify the UI about a successfully
     * received server response. 
     */
    public final static String INTENT_RESPONSE_OK = "com.tomtom.business.android.btdemo.intent.RESPONSE_OK";
    
    /**
     * This intent is broadcasted by the Response thread to notify the UI about a timeout
     * while waiting for the servers response.
     */
    public final static String INTENT_RESPONSE_TIMEOUT = "com.tomtom.business.android.btdemo.intent.RESPONSE_TIMEOUT";
    
    private SharedPreferences prefs = null;
    
    /**
     * ct.
     * @param prefs
     */
    Settings(SharedPreferences prefs)
    {
        this.prefs = prefs;
    }
    
    /**
     * Returns the value of the given setting.
     * @param name the name of the setting.
     * @param defaultValue the default value if it doesn't exist. Can be NULL too.
     * @return the value.
     */
    public String get(String name, String defaultValue)
    {
        return this.prefs.getString(name,defaultValue);
    }
    
    /**
     * Stores the given setting.
     * @param name name of the setting.
     * @param value value of the setting.
     */
    public void set(String name, String value)
    {
        Editor editor = this.prefs.edit();
        if (value == null)
            editor.remove(name);
        else
            editor.putString(name,value);

        editor.commit();
    }
}
